==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-session/lxqt-leave/lxqt-leave_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr_HR">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation type="unfinished">Napusti</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="29"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Što želite da računalo učini?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="45"/>
        <source>Logout</source>
        <translation type="unfinished">Odjava</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="57"/>
        <source>Reboot</source>
        <translation type="unfinished">Ponovno podizanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="69"/>
        <source>Shutdown</source>
        <translation type="unfinished">Isključivanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="81"/>
        <source>Suspend</source>
        <translation type="unfinished">suspenzija</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="93"/>
        <source>Lock screen</source>
        <translation type="unfinished">Zaključavanje zaslona</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="105"/>
        <source>Hibernate</source>
        <translation type="unfinished">Hibernacija</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="136"/>
        <source>Cancel</source>
        <translation type="unfinished">Otkaži</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation type="unfinished">Odjava.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation type="unfinished">Zaključaj zaslon.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation type="unfinished">Suspendiraj.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation type="unfinished">Hibernacija.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation type="unfinished">Isključi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation type="unfinished">Ponovno podigni.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-leave/lxqt-leave_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../../../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation type="unfinished">Napusti</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="59"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Što želite da računalo učini?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="92"/>
        <source>Logout</source>
        <translation type="unfinished">Odjava</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="206"/>
        <source>Reboot</source>
        <translation type="unfinished">Ponovno podizanje</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="186"/>
        <source>Shutdown</source>
        <translation type="unfinished">Isključivanje</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="139"/>
        <source>Suspend</source>
        <translation type="unfinished">suspenzija</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="112"/>
        <source>Lock screen</source>
        <translation type="unfinished">Zaključavanje zaslona</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="159"/>
        <source>Hibernate</source>
        <translation type="unfinished">Hibernacija</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Otkaži</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation type="unfinished">Odjava.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation type="unfinished">Zaključaj zaslon.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation type="unfinished">Suspendiraj.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation type="unfinished">Hibernacija.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation type="unfinished">Isključi.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation type="unfinished">Ponovno podigni.</translation>
    </message>
</context>
</TS>
